==> strongswan_4.4.1.orig.tar.gz: strongswan-4.4.1/src/libcharon/plugins/socket_raw/socket_raw_plugin.c <==
/*
 * Copyright (C) 2010 Martin Willi
 * Copyright (C) 2010 revosec AG
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  See <http://www.fsf.org/copyleft/gpl.txt>.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 */

#include "socket_raw_plugin.h"

#include "socket_raw_socket.h"

#include <daemon.h>

typedef struct private_socket_raw_plugin_t private_socket_raw_plugin_t;

/**
 * Private data of socket plugin
 */
struct private_socket_raw_plugin_t {

	/**
	 * Implements plugin interface
	 */
	socket_raw_plugin_t public;

	/**
	 * Raw socket instance.
	 */
	socket_raw_socket_t *socket;
};

METHOD(plugin_t, destroy, void,
	private_socket_raw_plugin_t *this)
{
	charon->socket->remove_socket(charon->socket, &this->socket->socket);
	this->socket->destroy(this->socket);
	free(this);
}

/*
 * see header file
 */
plugin_t *socket_raw_plugin_create()
{
	private_socket_raw_plugin_t *this;

	INIT(this,
		.public.plugin.destroy = _destroy,
		.socket = socket_raw_socket_create(),
	);

	if (!this->socket)
	{
		free(this);
		return NULL;
	}
	charon->socket->add_socket(charon->socket, &this->socket->socket);

	return &this->public.plugin;
}

==> strongswan_4.5.0.orig.tar.gz: strongswan-4.5.0/src/libcharon/plugins/socket_raw/socket_raw_plugin.c <==
/*
 * Copyright (C) 2010 Tobias Brunner
 * Hochschule fuer Technik Rapperswil
 * Copyright (C) 2010 Martin Willi
 * Copyright (C) 2010 revosec AG
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  See <http://www.fsf.org/copyleft/gpl.txt>.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 */

#include "socket_raw_plugin.h"

#include "socket_raw_socket.h"

#include <daemon.h>

typedef struct private_socket_raw_plugin_t private_socket_raw_plugin_t;

/**
 * Private data of socket plugin
 */
struct private_socket_raw_plugin_t {

	/**
	 * Implements plugin interface
	 */
	socket_raw_plugin_t public;

};

METHOD(plugin_t, destroy, void,
	private_socket_raw_plugin_t *this)
{
	charon->socket->remove_socket(charon->socket,
							(socket_constructor_t)socket_raw_socket_create);
	free(this);
}

/*
 * see header file
 */
plugin_t *socket_raw_plugin_create()
{
	private_socket_raw_plugin_t *this;

	INIT(this,
		.public = {
			.plugin = {
				.destroy = _destroy,
			},
		},
	);

	charon->socket->add_socket(charon->socket,
							(socket_constructor_t)socket_raw_socket_create);

	return &this->public.plugin;
}
